(cond-let & clauses)Takes ternary clauses which can use bindings visible to both the test and result expression, as well as all following clauses (except when shadowed); the last clause which can be binary and follows 'cond semantics. Each ternary clause can be of the form text-expr binding-vector result-expr or test-expr :>> result-expr if there are no new bindings added to the clause (:>> is an ordinary keyword)
Takes ternary clauses which can use bindings visible to both the test
and result expression, as well as all following clauses (except when shadowed);
the last clause which can be binary and follows 'cond semantics.
Each ternary clause can be of the form
text-expr binding-vector result-expr
or
test-expr :>> result-expr
if there are no new bindings added to the clause
(:>> is an ordinary keyword)
(cond-let> & clauses)Same as for cond-let, except bindings are local to each clause only.
Same as for cond-let, except bindings are local to each clause only.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |